@@ -1,5 +1,6 @@
-{-# LANGUAGE GADTs, DeriveFunctor, Rank2Types #-}
+{-# LANGUAGE GADTs, Rank2Types #-}
 module Options.Applicative.Types (
+  ParseError(..),
   ParserInfo(..),
   ParserPrefs(..),
 
@@ -19,6 +20,7 @@ module Options.Applicative.Types (
   fromM,
   oneM,
   manyM,
+  someM,
 
   optVisibility,
   optMetaVar,
@@ -27,10 +29,19 @@ module Options.Applicative.Types (
   ) where
 
 import Control.Applicative
-import Control.Monad
-import Control.Monad.Trans.Error
-import Data.Monoid
-import System.Exit
+  (Applicative(..), Alternative(..), (<$>), optional)
+import Control.Monad (ap, liftM)
+import Control.Monad.Trans.Error (Error(..))
+import Data.Monoid (Monoid(..))
+import System.Exit (ExitCode(..))
+
+data ParseError
+  = ErrorMsg String
+  | ShowHelpText
+  deriving Show
+
+instance Error ParseError where
+  strMsg = ErrorMsg
 
 -- | A full description for a runnable 'Parser' for a program.
 data ParserInfo a = ParserInfo
@@ -40,12 +51,17 @@ data ParserInfo a = ParserInfo
   , infoHeader :: String              -- ^ header of the full parser description
   , infoFooter :: String              -- ^ footer of the full parser description
   , infoFailureCode :: Int            -- ^ exit code for a parser failure
-  } deriving Functor
+  }
+
+instance Functor ParserInfo where
+  fmap f i = i { infoParser = fmap f (infoParser i) }
 
 -- | Global preferences for a top-level 'Parser'.
 data ParserPrefs = ParserPrefs
   { prefMultiSuffix :: String    -- ^ metavar suffix for multiple options
-  , prefDisambiguate :: Bool     -- ^ automatically disambiguate abbreviations
+  , prefDisambiguate :: Bool     -- ^ automatically disambiguate abbreviations (default: False)
+  , prefShowHelpOnError :: Bool  -- ^ always show help text on parse errors (default: False)
+  , prefBacktrack :: Bool        -- ^ backtrack to parent parser when a subcommand fails (default: True)
   }
 
 data OptName = OptShort !Char
@@ -71,20 +87,33 @@ data OptProperties = OptProperties
 data Option a = Option
   { optMain :: OptReader a               -- ^ reader for this option
   , optProps :: OptProperties            -- ^ properties of this option
-  } deriving Functor
+  }
 
-data CReader a = CReader
+instance Functor Option where
+  fmap f (Option m p) = Option (fmap f m) p
+
+data CReader m a = CReader
   { crCompleter :: Completer
-  , crReader :: String -> Maybe a }
-  deriving Functor
+  , crReader :: String -> m a }
+
+instance Functor m => Functor (CReader m) where
+  fmap f (CReader c r) = CReader c (fmap f . r)
+
+type OptCReader = CReader (Either ParseError)
+type ArgCReader = CReader Maybe
 
 -- | An 'OptReader' defines whether an option matches an command line argument.
 data OptReader a
-  = OptReader [OptName] (CReader a)                     -- ^ option reader
+  = OptReader [OptName] (OptCReader a) ParseError       -- ^ option reader
   | FlagReader [OptName] !a                             -- ^ flag reader
-  | ArgReader (CReader a)                               -- ^ argument reader
+  | ArgReader (ArgCReader a)                            -- ^ argument reader
   | CmdReader [String] (String -> Maybe (ParserInfo a)) -- ^ command reader
-  deriving Functor
+
+instance Functor OptReader where
+  fmap f (OptReader ns cr e) = OptReader ns (fmap f cr) e
+  fmap f (FlagReader ns x) = FlagReader ns (f x)
+  fmap f (ArgReader cr) = ArgReader (fmap f cr)
+  fmap f (CmdReader cs g) = CmdReader cs ((fmap . fmap) f . g)
 
 -- | A @Parser a@ is an option parser returning a value of type 'a'.
 data Parser a where
@@ -132,6 +161,9 @@ manyM p = do
     Nothing -> return []
     Just x -> (x:) <$> manyM p
 
+someM :: Parser a -> ParserM [a]
+someM p = (:) <$> oneM p <*> manyM p
+
 instance Alternative Parser where
   empty = NilP Nothing
   (<|>) = AltP
@@ -166,7 +198,7 @@ data OptTree a
   = Leaf a
   | MultNode [OptTree a]
   | AltNode [OptTree a]
-  deriving (Functor, Show)
+  deriving Show
 
 optVisibility :: Option a -> OptVisibility
 optVisibility = propVisibility . optProps
