@@ -11,11 +11,11 @@ sample :: Parser Sample
 sample = Sample
      <$> strOption
          ( long "hello"
-         & metavar "TARGET"
-         & help "Target for the greeting" )
+        <> metavar "TARGET"
+        <> help "Target for the greeting" )
      <*> switch
          ( long "quiet"
-         & help "Whether to be quiet" )
+        <> help "Whether to be quiet" )
 
 greet :: Sample -> IO ()
 greet (Sample h False) = putStrLn $ "Hello, " ++ h
@@ -27,5 +27,5 @@ main = execParser opts >>= greet
 opts :: ParserInfo Sample
 opts = info (sample <**> helper)
   ( fullDesc
-  & progDesc "Print a greeting for TARGET"
-  & header "hello - a test for optparse-applicative" )
+ <> progDesc "Print a greeting for TARGET"
+ <> header "hello - a test for optparse-applicative" )
